<?php

declare(strict_types=1);

namespace Drupal\sites_migrator\Commands;

use Drupal\sites_migrator\MenuConfigMigrator;
use Drupal\sites_migrator\MenuContentMigrator;
use Drush\Attributes\Argument;
use Drush\Attributes\Command;
use Drush\Attributes\Usage;
use Drush\Commands\DrushCommands;

class MenuMigrationCommands extends DrushCommands {

  public function __construct(
    private readonly MenuContentMigrator $menuContentMigrator,
    private readonly MenuConfigMigrator $menuConfigMigrator,
  ) {
    parent::__construct();
  }

  #[Command(name: 'sites-migrator:migrate-menu-content', aliases: ['sm:migrate-menu-content'])]
  #[Argument(name: 'sourceMenuName', description: 'The machine name of the source Drupal core menu. E.g. "mie-demo-base-menu".')]
  #[Argument(name: 'groupId', description: 'The numeric ID of the group. E.g. "2".')]
  #[Argument(name: 'groupMenuBundle', description: 'The bundle of the group content menu. E.g. "basic_menu".')]
  #[Argument(name: 'menuLabel', description: 'The menu label. E.g. "Example Menu".')]
  #[Usage(name: 'sites-migrator:migrate-menu-content mie-demo-base-menu 2 basic_menu "Example Menu"', description: 'Migrates a menu tree into group content menu.')]
  public function migrateMenuContent(string $sourceMenuName, int $groupId, string $groupMenuBundle, string $menuLabel): void {
    try {
      $this->menuContentMigrator->migrateMenuItems($sourceMenuName, $groupId, $groupMenuBundle, $menuLabel, $this->output());
      $this->io()->success(dt('Menu content migrated.'));
    }
    catch (\Exception $e) {
      $this->logger()->error('Migration failed: ' . $e->getMessage());
      $this->io()->error('Migration failed: ' . $e->getMessage());
    }
  }

  #[Command(name: 'sites-migrator:migrate-menu-config', aliases: ['sm:migrate-menu-config'])]
  #[Argument(name: 'sourceMenuName', description: 'The machine name of the source Drupal core menu.')]
  #[Usage(name: 'sites-migrator:migrate-menu-config main', description: 'Migrates a non-group menu config into a menu with leverages the group_content_menu_bundles module. Fields from menu_item_extras module will be also migrated.')]
  public function migrateMenuConfig(string $sourceMenuName): void {
    try {
      $this->menuConfigMigrator->migrateMenuTypeConfig($sourceMenuName);
      $this->io()->success(dt('Menu config migrated. Do not forget to export your config.'));
    }
    catch (\Exception $e) {
      $this->logger()->error('Migration failed: ' . $e->getMessage());
      $this->io()->error('Migration failed: ' . $e->getMessage());
    }
  }

}
